# U Fancy

## Purpose
- Provide convenient higher-level interfaces for faster devops

## Development
- Lots to do, lost interest in creating a unified UI for now
- Look out for composable components in the future

## Ideal World
- U Fancy would be a one stop shop for PyQt, Beeware, and Vue.js.
    - Instead of programming in each one, a custom AST would target the architecture during packaging (ex. Briefcase)
    
## Purpose
- High-level components for C-suite comms, let the worker bees implement architecture specific AST concretes :P
